##########
#
#  Copyright 2002, Tom Hoffman.
# 
#  This file is part of Tuttle.
#
#  Tuttle is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Tuttle is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Tuttle (see COPYING.txt); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##########

from OFS.Folder import Folder
from Globals import DTMLFile
from Acquisition import Implicit
from Products.ZCatalog.CatalogPathAwareness import CatalogAware
from StudentsFolder import StudentsFolder
from TeachersFolder import TeachersFolder
import string

def manage_addSchoolInfo(self,id,title,\
district,superintendent,REQUEST):
	"Method for adding a Tuttle site"
	newSchool = SchoolInfo(id,title,district,superintendent)
	# add a folder for students
	studFolder=StudentsFolder('student', title + ' Student Records')
	newSchool._setObject('student',studFolder)
	# add a folder for teachers
	teachFolder=TeachersFolder('teacher', title + ' Teacher Files')
	newSchool._setObject('teacher',teachFolder)

	self._setObject(id, newSchool)
	return self.manage_main(self, REQUEST)

# web interface methods
manage_addSchoolInfoForm = DTMLFile("dtml/addSchoolInfoForm", globals())

class SchoolInfo(Folder):
        """
	The SchoolInfo Class
	This class is the heart of a Tuttle Site.
	It contains the default site configuration options,
	as well as the basic "API" for returning student
	and teacher data
	"""
	
	meta_type = "Tuttle School Site"
   
	################################
	#                              #
	#  Site Configuration Options  #
        #                              # 
	################################

        # A list of the grades or levels in the school
        # e.g., in traditional (high) schools, GradeLevelList would be ['9','10','11','12']
        GradeLevelList=['9', '10','11','12']
        
        # If students and teachers are organized into teams, academies, etc.
        TeamList=['red','blue','yellow','black'] # these teams include teachers and students
        TeacherTeamList = TeamList + ['No Team'] # additional "teams" for teachers only
        
        # These need to be updated in a few years...
        # Graduation Years
        GradYearList=["2003","2004","2005","2006"]

	# These are all the subjects taught in the school
	SubjectList=['English','Social Studies','Mathematics','Science','ESL',\
	'Health and Physical Education','Spanish','French','Art','Music']

	Genders=('Male','Female')

	def __init__ (self, id, title,\
	district="Unknown School District", \
        superintendent="Unknown"):
		"To do: add more of the attributes in the SIF model."
		self.id=id
		self.title=title # maps to SIF.SchoolInfo.SchoolName
		self.district=district
		self.superintendent=superintendent
	
	# declare properties
	_properties=(
	{'id':'title', 'type':'string'},
	{'id':'district', 'type':'string'},
	{'id':'superintendent','type':'string'},
	{'id':'GradeLevelList','type':'lines'},
	{'id':'TeamList','type':'lines'},
	{'id':'TeacherTeamList','type':'lines'},
	{'id':'SubjectList','type':'lines'},
	{'id':'GradYearList','type':'lines'},
	)

	# Class level functions and (web) methods 
	manage_edit=DTMLFile("dtml/mainSchoolInfo", globals())
	index_html=DTMLFile("dtml/indexSchoolInfo", globals())

	def editSchoolInfo(self, title, district, superintendent,REQUEST):
		"Edit School Properties"
		
		self.title=title
		self.district=district
		self.superintendent=superintendent
		self.reindex_object()
		return self.index_html(self, REQUEST)

	#################################################
	#                                               #
	# Tuttle <fingerquote>API</fingerquote> methods #
	#						#
	#################################################

	def getInfo (self, role, userid, Method):
		"""This method allows you to make an arbitrary call on a
		student or teacher object
		role is 'student' or 'teacher'"""
		call=""
		CodeString = "call = self." + role +  "." + userid + "." + Method
		exec CodeString
		return call

	# these methods cover various formats for people's names

	def getFullName (self, role, userid):
		"Returns 'First Middle Last'"
		first = self.getInfo (role, userid, 'FirstName')
		middle = self.getInfo (role, userid, 'MiddleName')
		last = self.getInfo (role, userid, 'LastName')
		if middle:
			fullname=string.join([first,middle], " ")
		else:
			fullname=first
		fullname=string.join([fullname,last], " ")
		return fullname

	def getFullerName (self, role, userid):
		"Returns 'Prefix First Middle Last Suffix'"
		fullername = self.getFullName (role, userid)
		fullername = self.addPrefixSuffix (role, userid, fullername)
		return fullername

	def addPrefixSuffix (self, role, userid, name):
		"Adds prefix and suffix"
		prefix=""
		if role != 'student':
			prefix = self.getInfo (role, userid, 'Prefix')
		suffix = self.getInfo (role, userid, 'Suffix')
		if prefix :
			name=string.join([prefix, name], " ")
		if suffix:
			name=string.join([name, suffix], " ")
		return name

	def getFullestName (self, role, userid):
		"""Returns name in form 
		'Prefix FirstName MiddleName (PreferredName) LastName Suffix'"""
		fullestname = self.getFullName(role, userid)
		pref = self.getInfo (role, userid, 'PreferredName')
		if pref:		
			pref = string.join(['(', pref, ')'],"")
			pref = [pref]
			fullestname=string.split(fullestname, ' ',)
			fullestname=fullestname[:-1] + pref + fullestname[-1:]
			fullestname=string.join(fullestname, " ")
		fullestname = self.addPrefixSuffix(role, userid, fullestname)
		return fullestname

	def getTeamMembers (self, role, team="no team"):
		'Returns a list of ids for the members of a team, or all members'
		call = []
		result = []
		codestring = "call = self." + role + ".objectIds(\'" + role + "\')"
		exec codestring
		for name in call:
			if team == "no team" or team == self.getInfo(role, name, 'Team'):
				result.append (name)
		return result
			 
