##########
#
#  Copyright 2002, Tom Hoffman.
# 
#  This file is part of Tuttle.
#
#  Tuttle is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Tuttle is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Tuttle (see COPYING.txt); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##########

from OFS.Folder import Folder
from StudentPersonal import StudentPersonal
from Globals import DTMLFile
import SchoolInfo
import string


class StudentsFolder(Folder):
    "These objects contain individual student folders."
    
    meta_type="Students Folder"
    
    _properties=(
    {'id':'title', 'type':'string'},
    )

    manage_options=Folder.manage_options[:3] + (
    {'label':'Add Student','action':'manage_addStudentPersonalForm'},
    {'label':'Import','action':'manage_importStudentPersonalFile'}
    ) + Folder.manage_options[3:]

    def __init__ (self,id,title):
        self.id=id
	self.title=title

    # methods to add, edit and retrieve StudentPersonal instances

    def addStudentPersonal(self, id, FirstName, LastName, MiddleName, PreferredName, \
    Suffix, Gender, GradeLevel, GradYear, Team, REQUEST=None):
        "Method to add a StudentPersonal object to a StudentsFolder"
        newStudentPersonal=StudentPersonal(id, FirstName, LastName, MiddleName, \
        PreferredName, Suffix, Gender, GradeLevel, GradYear, Team) 
        self._setObject(id, newStudentPersonal)
    	if REQUEST is not None:
            return self.manage_main(self, REQUEST)
            
    def importStudentPersonalFile(self,REQUEST):
        "Imports a comma-delimited text file of StudentPersonal records"
        # this method is looking for a comma-delimited text file of StudentPersonal data
        # the format is: 
        # id,LastName,Suffix,FirstName,MiddleName,PreferredName,Gender,GradeLevel,GradYear,Team
        # e.g.: thoffman,Hoffman,,Thomas,E,Tom,M,11,1987,Cats
        # note: leave no extra spaces
        # to do: make this more flexible and configurable through the web
        
        records=string.split(REQUEST.StudentListFile,'\n')
        for each in records:
            if each:
                ss=string.split(each,',')
                # had to knock off an \r at the end of each line
                # need to do this more intelligently
                ss[9]=ss[9][:-1]
                # this is a little awkward because I'm switching the order of the parameters
                # to make them closer to the order in which a database would typically report them
                newStudentPersonal=StudentPersonal(ss[0],ss[3],ss[1],ss[4],ss[5]\
                ,ss[2],ss[6],ss[7],ss[8],ss[9])
                self._setObject(ss[0], newStudentPersonal)
        return self.manage_main(self,REQUEST)
    
    manage_addStudentPersonalForm=DTMLFile("dtml/addStudentPersonalForm",globals())
    manage_importStudentPersonalFile=DTMLFile("dtml/importStudentPersonalFileForm",globals())
